Green Unicorn - Welcome

# gunicorn

Get the source via git, then send feedback

# Green Unicorn

Green Unicorn (gunicorn) is an HTTP/WSGI Server for UNIX designed to serve fast clients or sleepy applications.

This is a port of Unicorn in Python. Meet us on the #gunicorn IRC channel on Freenode.

Gunicorn is released under the MIT License. See the LICENSE for more details.

# Features

- Designed for Unix, WSGI, fast clients and sleepy applications.
- Compatible with Python 2.x (>= 2.5)
- Easy integration with Django and Paster compatible applications (Pylons, TurboGears 2, ...)
- Process management: Gunicorn reaps and restarts workers that die.
- Load balancing via pre-fork and a shared socket
- Graceful worker process restarts
- Upgrade "àla nginx" without losing connections
- Simple and easy Python configuration
- Decode chunked transfers on-the-fly, allowing upload progress notifications or stream-based protocols over HTTP
- Support for Eventlet and Gevent .
- Post- and pre-fork hooks

# Applications

- Any WSGI, Django and Paster compatible applications (Pylons, TurboGears 2, ...)
- Websockets (see the example or the screencast)
- Reverse proxy implementation (with Restkit WSGI proxy)
- Comet
- Long Polling